@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2008-2021 EDF R&D
+# Copyright (C) 2008-2022 EDF R&D
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -20,9 +20,9 @@
 #
 # Author: Jean-Philippe Argaud, jean-philippe.argaud@edf.fr, EDF R&D
 
-import logging
-from daCore import BasicObjects, NumericObjects
-import numpy, scipy.optimize, scipy.version
+import numpy
+from daCore import BasicObjects
+from daAlgorithms.Atoms import std4dvar
 
 # ==============================================================================
 class ElementaryAlgorithm(BasicObjects.Algorithm):
@@ -62,11 +62,12 @@ class ElementaryAlgorithm(BasicObjects.Algorithm):
             listval  = ["LBFGSB","TNC", "CG", "NCG", "BFGS"],
             )
         self.defineRequiredParameter(
-            name     = "MaximumNumberOfSteps",
+            name     = "MaximumNumberOfIterations",
             default  = 15000,
             typecast = int,
             message  = "Nombre maximal de pas d'optimisation",
             minval   = -1,
+            oldname  = "MaximumNumberOfSteps",
             )
         self.defineRequiredParameter(
             name     = "CostDecrementTolerance",
@@ -126,7 +127,7 @@ class ElementaryAlgorithm(BasicObjects.Algorithm):
             )
         self.requireInputArguments(
             mandatory= ("Xb", "Y", "HO", "EM", "R", "B" ),
-            optional = ("U", "CM"),
+            optional = ("U", "CM", "Q"),
             )
         self.setAttributes(tags=(
             "DataAssimilation",
@@ -141,7 +142,7 @@ class ElementaryAlgorithm(BasicObjects.Algorithm):
         #--------------------------
         # Default 4DVAR
         if   self._parameters["Variant"] in ["4DVAR", "4DVAR-Std"]:
-            NumericObjects.std4dvar(self, Xb, Y, U, HO, EM, CM, R, B, Q)
+            std4dvar.std4dvar(self, Xb, Y, U, HO, EM, CM, R, B, Q)
         #
         #--------------------------
         else:
