@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2008-2021 EDF R&D
+# Copyright (C) 2008-2022 EDF R&D
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -20,8 +20,8 @@
 #
 # Author: Jean-Philippe Argaud, jean-philippe.argaud@edf.fr, EDF R&D
 
-import logging
-from daCore import BasicObjects, NumericObjects
+from daCore import BasicObjects
+from daAlgorithms.Atoms import c2ukf, uskf
 
 # ==============================================================================
 class ElementaryAlgorithm(BasicObjects.Algorithm):
@@ -37,13 +37,6 @@ class ElementaryAlgorithm(BasicObjects.Algorithm):
                 "2UKF",
                 ],
             )
-        self.defineRequiredParameter(
-            name     = "ConstrainedBy",
-            default  = "EstimateProjection",
-            typecast = str,
-            message  = "Prise en compte des contraintes",
-            listval  = ["EstimateProjection"],
-            )
         self.defineRequiredParameter(
             name     = "EstimationOf",
             default  = "State",
@@ -51,6 +44,13 @@ class ElementaryAlgorithm(BasicObjects.Algorithm):
             message  = "Estimation d'etat ou de parametres",
             listval  = ["State", "Parameters"],
             )
+        self.defineRequiredParameter(
+            name     = "ConstrainedBy",
+            default  = "EstimateProjection",
+            typecast = str,
+            message  = "Prise en compte des contraintes",
+            listval  = ["EstimateProjection"],
+            )
         self.defineRequiredParameter(
             name     = "Alpha",
             default  = 1.,
@@ -104,7 +104,6 @@ class ElementaryAlgorithm(BasicObjects.Algorithm):
                 "CostFunctionJbAtCurrentOptimum",
                 "CostFunctionJo",
                 "CostFunctionJoAtCurrentOptimum",
-                "CurrentIterationNumber",
                 "CurrentOptimum",
                 "CurrentState",
                 "ForecastCovariance",
@@ -140,12 +139,12 @@ class ElementaryAlgorithm(BasicObjects.Algorithm):
         # Default UKF
         #--------------------------
         if   self._parameters["Variant"] == "UKF":
-            NumericObjects.uskf(self, Xb, Y, U, HO, EM, CM, R, B, Q)
+            uskf.uskf(self, Xb, Y, U, HO, EM, CM, R, B, Q)
         #
         #--------------------------
         # Default 2UKF
         elif self._parameters["Variant"] == "2UKF":
-            NumericObjects.c2ukf(self, Xb, Y, U, HO, EM, CM, R, B, Q)
+            c2ukf.c2ukf(self, Xb, Y, U, HO, EM, CM, R, B, Q)
         #
         #--------------------------
         else:
