@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2008-2021 EDF R&D
+# Copyright (C) 2008-2022 EDF R&D
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -98,13 +98,18 @@ class PlatformInfo(object):
                 __msg += "\n%s%30s : %s" %(__prefix,"platform.dist",str(platform.dist()))
         elif sys.platform.startswith('darwin'):
             if hasattr(platform, 'mac_ver'):
-                __macosxv = {'5': 'Leopard',       '6': 'Snow Leopard', '7': 'Lion',
-                             '8': 'Mountain Lion', '9': 'Mavericks',   '10': 'Yosemite',
-                             '11': 'El Capitan',  '12': 'Sierra'}
+                __macosxv = {
+                    '0' : 'Cheetah',      '1' : 'Puma',        '2' : 'Jaguar',
+                    '3' : 'Panther',      '4' : 'Tiger',       '5' : 'Leopard',
+                    '6' : 'Snow Leopard', '7' : 'Lion',        '8' : 'Mountain Lion',
+                    '9' : 'Mavericks',    '10': 'Yosemite',    '11': 'El Capitan',
+                    '12': 'Sierra',       '13': 'High Sierra', '14': 'Mojave',
+                    '15': 'Catalina',     '16': 'Big Sur',     '17': 'Monterey',
+                    }
                 for key in __macosxv:
                     if (platform.mac_ver()[0].split('.')[1] == key):
                         __msg += "\n%s%30s : %s" %(__prefix,
-                            "platform.mac_ver",str(platform.mac_ver()[0]+"(" + macosx_dict[key]+")"))
+                            "platform.mac_ver",str(platform.mac_ver()[0]+"(" + __macosxv[key]+")"))
             elif hasattr(platform, 'dist'):
                 __msg += "\n%s%30s : %s" %(__prefix,"platform.dist",str(platform.dist()))
         elif os.name == 'nt':
@@ -180,6 +185,14 @@ class PlatformInfo(object):
             __version = "0.0.0"
         return __version
 
+    def getSdfVersion(self):
+        "Retourne la version de sdf disponible"
+        if has_sdf:
+            __version = sdf.__version__
+        else:
+            __version = "0.0.0"
+        return __version
+
     def getCurrentMemorySize(self):
         "Retourne la taille mémoire courante utilisée"
         return 1
@@ -206,6 +219,7 @@ class PlatformInfo(object):
         import daCore.version as dav
         return "%s %s (%s)"%(dav.name,dav.version,dav.date)
 
+
 # ==============================================================================
 try:
     import scipy
@@ -245,9 +259,9 @@ try:
 except ImportError:
     has_sdf = False
 
-has_salome = bool( "ROOT_SALOME"   in os.environ )
-has_yacs   = bool( "YACS_ROOT_DIR" in os.environ )
-has_adao   = bool( "ADAO_ROOT_DIR" in os.environ )
+has_salome = bool( "SALOME_ROOT_DIR" in os.environ )
+has_yacs   = bool(   "YACS_ROOT_DIR" in os.environ )
+has_adao   = bool(   "ADAO_ROOT_DIR" in os.environ )
 has_eficas = bool( "EFICAS_ROOT_DIR" in os.environ )
 
 # ==============================================================================
@@ -317,9 +331,9 @@ def strmatrix2liststr( __strvect ):
     __strvect = __strvect.replace(","," ") # Blanc
     for s in ("]", ")"):
         __strvect = __strvect.replace(s,";") # "]" et ")" par ";"
-    __strvect = re.sub(';\s*;',';',__strvect)
+    __strvect = re.sub(r';\s*;',r';',__strvect)
     __strvect = __strvect.rstrip(";") # Après ^ et avant v
-    __strmat = [l.split() for l in __strvect.split(";")]
+    __strmat = [__l.split() for __l in __strvect.split(";")]
     return __strmat
 
 def checkFileNameConformity( __filename, __warnInsteadOfPrint=True ):
@@ -368,7 +382,7 @@ class PathManagement(object):
         self.__paths["daNumerics"]  = os.path.join(parent,"daNumerics")
         #
         for v in self.__paths.values():
-            sys.path.insert(0, v )
+            if os.path.isdir(v): sys.path.insert(0, v )
         #
         # Conserve en unique exemplaire chaque chemin
         sys.path = uniq( sys.path )
@@ -480,6 +494,7 @@ class SystemUsage(object):
         "Renvoie la mémoire totale maximale mesurée"
         return self._VmB('VmPeak:', unit)
 
+
 # ==============================================================================
 if __name__ == "__main__":
     print('\n AUTODIAGNOSTIC\n')
