@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2008-2021 EDF R&D
+# Copyright (C) 2008-2022 EDF R&D
 #
 # This file is part of SALOME ADAO module
 #
@@ -25,6 +25,7 @@
 import ADAO_COMPONENT__POA
 import SALOME_ComponentPy
 import SALOME_DriverPy
+import SALOME_Embedded_NamingService_ClientPy
 
 from daUtils.adaoLogger import *
 
@@ -46,7 +47,14 @@ class ADAO(ADAO_COMPONENT__POA.ADAO_ENGINE,
     SALOME_DriverPy.SALOME_DriverPy_i.__init__(self, interfaceName)
 
     # On stocke dans l'attribut _naming_service, une ref sur le Naming Service
-    self._naming_service = SALOME_ComponentPy.SALOME_NamingServicePy_i( self._orb )
+    #
+    emb_ns = self._contId.get_embedded_NS_if_ssl()
+    import CORBA
+    if CORBA.is_nil(emb_ns):
+        self._naming_service = SALOME_ComponentPy.SALOME_NamingServicePy_i( self._orb )
+    else:
+        self._naming_service = SALOME_Embedded_NamingService_ClientPy.SALOME_Embedded_NamingService_ClientPy(emb_ns)
+    #
 
   def print_ping():
     info("ADAO ENGINE Ping", "ENGINE")
